==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/IdentityModelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Identity model.
 * @property aadAuthority Gets or sets the authority of the SPN with which Dra communicates to service.
 * @property applicationId Gets or sets the client/application Id of the SPN with which Dra communicates to
 * service.
 * @property audience Gets or sets the audience of the SPN with which Dra communicates to service.
 * @property objectId Gets or sets the object Id of the SPN with which Dra communicates to service.
 * @property tenantId Gets or sets the tenant Id of the SPN with which Dra communicates to service.
 */
public data class IdentityModelArgs(
    public val aadAuthority: Output<String>,
    public val applicationId: Output<String>,
    public val audience: Output<String>,
    public val objectId: Output<String>,
    public val tenantId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs> {
    override fun toJava(): com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs =
        com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs.builder()
            .aadAuthority(aadAuthority.applyValue({ args0 -> args0 }))
            .applicationId(applicationId.applyValue({ args0 -> args0 }))
            .audience(audience.applyValue({ args0 -> args0 }))
            .objectId(objectId.applyValue({ args0 -> args0 }))
            .tenantId(tenantId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IdentityModelArgs].
 */
@PulumiTagMarker
public class IdentityModelArgsBuilder internal constructor() {
    private var aadAuthority: Output<String>? = null

    private var applicationId: Output<String>? = null

    private var audience: Output<String>? = null

    private var objectId: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Gets or sets the authority of the SPN with which Dra communicates to service.
     */
    @JvmName("gmnjviufpcaswkym")
    public suspend fun aadAuthority(`value`: Output<String>) {
        this.aadAuthority = value
    }

    /**
     * @param value Gets or sets the client/application Id of the SPN with which Dra communicates to
     * service.
     */
    @JvmName("jtlqfporvvvupmhy")
    public suspend fun applicationId(`value`: Output<String>) {
        this.applicationId = value
    }

    /**
     * @param value Gets or sets the audience of the SPN with which Dra communicates to service.
     */
    @JvmName("dfevjeovujspfdly")
    public suspend fun audience(`value`: Output<String>) {
        this.audience = value
    }

    /**
     * @param value Gets or sets the object Id of the SPN with which Dra communicates to service.
     */
    @JvmName("lwcytfjgpmgkbakj")
    public suspend fun objectId(`value`: Output<String>) {
        this.objectId = value
    }

    /**
     * @param value Gets or sets the tenant Id of the SPN with which Dra communicates to service.
     */
    @JvmName("acwbdmkccjfhubox")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Gets or sets the authority of the SPN with which Dra communicates to service.
     */
    @JvmName("skmcjxmyciwgsgof")
    public suspend fun aadAuthority(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.aadAuthority = mapped
    }

    /**
     * @param value Gets or sets the client/application Id of the SPN with which Dra communicates to
     * service.
     */
    @JvmName("hbtrqesokijapofd")
    public suspend fun applicationId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationId = mapped
    }

    /**
     * @param value Gets or sets the audience of the SPN with which Dra communicates to service.
     */
    @JvmName("fisnugbjhhqhhawl")
    public suspend fun audience(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.audience = mapped
    }

    /**
     * @param value Gets or sets the object Id of the SPN with which Dra communicates to service.
     */
    @JvmName("clrnfxtxhoqkywxo")
    public suspend fun objectId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectId = mapped
    }

    /**
     * @param value Gets or sets the tenant Id of the SPN with which Dra communicates to service.
     */
    @JvmName("hixexltisbeollyu")
    public suspend fun tenantId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): IdentityModelArgs = IdentityModelArgs(
        aadAuthority = aadAuthority ?: throw PulumiNullFieldException("aadAuthority"),
        applicationId = applicationId ?: throw PulumiNullFieldException("applicationId"),
        audience = audience ?: throw PulumiNullFieldException("audience"),
        objectId = objectId ?: throw PulumiNullFieldException("objectId"),
        tenantId = tenantId ?: throw PulumiNullFieldException("tenantId"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/IdentityModelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Identity model.
 * @property aadAuthority Gets or sets the authority of the SPN with which Dra communicates to service.
 * @property applicationId Gets or sets the client/application Id of the SPN with which Dra communicates to
 * service.
 * @property audience Gets or sets the audience of the SPN with which Dra communicates to service.
 * @property objectId Gets or sets the object Id of the SPN with which Dra communicates to service.
 * @property tenantId Gets or sets the tenant Id of the SPN with which Dra communicates to service.
 */
public data class IdentityModelArgs(
    public val aadAuthority: Output<String>,
    public val applicationId: Output<String>,
    public val audience: Output<String>,
    public val objectId: Output<String>,
    public val tenantId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs> {
    override fun toJava(): com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs =
        com.pulumi.azurenative.datareplication.inputs.IdentityModelArgs.builder()
            .aadAuthority(aadAuthority.applyValue({ args0 -> args0 }))
            .applicationId(applicationId.applyValue({ args0 -> args0 }))
            .audience(audience.applyValue({ args0 -> args0 }))
            .objectId(objectId.applyValue({ args0 -> args0 }))
            .tenantId(tenantId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IdentityModelArgs].
 */
@PulumiTagMarker
public class IdentityModelArgsBuilder internal constructor() {
    private var aadAuthority: Output<String>? = null

    private var applicationId: Output<String>? = null

    private var audience: Output<String>? = null

    private var objectId: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Gets or sets the authority of the SPN with which Dra communicates to service.
     */
    @JvmName("gdyujdhahmdounsj")
    public suspend fun aadAuthority(`value`: Output<String>) {
        this.aadAuthority = value
    }

    /**
     * @param value Gets or sets the client/application Id of the SPN with which Dra communicates to
     * service.
     */
    @JvmName("rbrbftmhjqtvkpyp")
    public suspend fun applicationId(`value`: Output<String>) {
        this.applicationId = value
    }

    /**
     * @param value Gets or sets the audience of the SPN with which Dra communicates to service.
     */
    @JvmName("opmrksberkfgbpmk")
    public suspend fun audience(`value`: Output<String>) {
        this.audience = value
    }

    /**
     * @param value Gets or sets the object Id of the SPN with which Dra communicates to service.
     */
    @JvmName("maxqpdqdelugslla")
    public suspend fun objectId(`value`: Output<String>) {
        this.objectId = value
    }

    /**
     * @param value Gets or sets the tenant Id of the SPN with which Dra communicates to service.
     */
    @JvmName("lrrmettecddcfcpl")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Gets or sets the authority of the SPN with which Dra communicates to service.
     */
    @JvmName("wxxyihqiwguqvahk")
    public suspend fun aadAuthority(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.aadAuthority = mapped
    }

    /**
     * @param value Gets or sets the client/application Id of the SPN with which Dra communicates to
     * service.
     */
    @JvmName("nthxkoagjhveyoll")
    public suspend fun applicationId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationId = mapped
    }

    /**
     * @param value Gets or sets the audience of the SPN with which Dra communicates to service.
     */
    @JvmName("vbeuvopayultqqcs")
    public suspend fun audience(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.audience = mapped
    }

    /**
     * @param value Gets or sets the object Id of the SPN with which Dra communicates to service.
     */
    @JvmName("pqfybcfjufruxgyd")
    public suspend fun objectId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectId = mapped
    }

    /**
     * @param value Gets or sets the tenant Id of the SPN with which Dra communicates to service.
     */
    @JvmName("isgqjcajpbbvlxft")
    public suspend fun tenantId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): IdentityModelArgs = IdentityModelArgs(
        aadAuthority = aadAuthority ?: throw PulumiNullFieldException("aadAuthority"),
        applicationId = applicationId ?: throw PulumiNullFieldException("applicationId"),
        audience = audience ?: throw PulumiNullFieldException("audience"),
        objectId = objectId ?: throw PulumiNullFieldException("objectId"),
        tenantId = tenantId ?: throw PulumiNullFieldException("tenantId"),
    )
}
